/// <reference path="lodash.d.ts" />
/// <reference path="three.d.ts" />
/// <reference path="Utils.d.ts" />
/// <reference path="OrbitalMechanics.d.ts" />
/// <reference path="Rings.d.ts" />
/// <reference path="SOITree.d.ts" />
/// <reference path="SolarSystem.d.ts" />
/// <reference path="Labels.d.ts" />
declare class Body {
    name: string;
    data: BodyData;
    kind: string;
    radius: number;
    color: Color;
    material: THREE.Material;
    orbitData: OrbitData;
    rotationData: RotationData;
    orbit: Orbit;
    rotation: Rotation;
    constructor(name: string, data: BodyData, kind?: string);
    toString(): string;
}
/**
 * Responsible for rendering one SOI level.
 */
declare class LevelRenderer {
    node: SOINode;
    treeRenderer: SOITreeRenderer;
    scene: THREE.Scene;
    private _setUp;
    constructor(node: SOINode, treeRenderer: SOITreeRenderer, scene?: THREE.Scene);
    setUp(): void;
    tearDown(): void;
    private makeNodeRenderer(node);
    onUpdatePosition(curPos: Vector3): void;
    private getNodes();
}
interface NodeRenderer {
    setUp(): any;
    tearDown(): any;
    update(relPos: Vector3, cursorPos: Vector3): any;
}
/** A level of detail mesh definition. */
interface LOD {
    /** The minimum angular diameter to activate this LOD. */
    angularDiameter: number;
    /** The level of detail number */
    detail: number;
    /** The mesh at the current LOD. */
    mesh: THREE.Mesh;
}
declare class SphericalNodeRenderer implements NodeRenderer {
    node: SOINode;
    body: Body;
    levelRenderer: LevelRenderer;
    scene: THREE.Scene;
    private _setUp;
    private _sceneTargets;
    label: Label;
    meshes: LOD[];
    currentLOD: number;
    angularDiameters: number[];
    details: number[];
    line: THREE.Line;
    updateOrbit: () => void;
    constructor(node: SOINode, body: Body, levelRenderer: LevelRenderer, scene?: THREE.Scene);
    private _ensureOrbitLine();
    private _updatePosition();
    private _updateRotation(mesh);
    /**
     * Update the sphere's position based on this object's displacement to the
     * cursor (displacement is actually position in WebGL world space).
     */
    update(relPos: Vector3, cursorPos: Vector3): void;
    setUp(): void;
    tearDown(): void;
    private ensureLOD(index);
    private removeLOD(index);
    private select(index);
    private deselect(index);
}
declare class SOITreeRenderer {
    tree: SOITree;
    scene: THREE.Scene;
    cursor: SOICursor;
    renderers: LevelRenderer[];
    constructor(tree: SOITree, scene: THREE.Scene, cursor?: SOICursor);
    private pushRenderer(node);
    private popRenderer();
    private getTopRenderer();
    private getLevel(node);
    moveCursor(delta: Vector3): void;
    getRelativePositionTo(node: SOINode): THREE.Vector3;
}
declare function getSolarSystem(): SOITree;
