/// <reference path="three.d.ts" />
/// <reference path="Utils.d.ts" />
/** Plot function f : R -> R^3 */
declare function MakePlot(f: (t: number, v: Vector3) => void, mat: THREE.LineDashedMaterial | THREE.LineBasicMaterial | THREE.ShaderMaterial, params: {
    closed?: boolean;
    t0?: number;
    t1?: number;
    dt?: number;
}): {
    line: THREE.Line;
    updateGeom: () => void;
};
interface OrbitData {
    semiMajorAxis: number;
    eccentricity?: number;
    period: number;
    phase?: number;
    inclination?: number;
    argumentOfPeriapsis?: number;
    longitudeOfAscendingNode?: number;
}
interface RotationData {
    period: number;
    tilt?: number;
    phase?: number;
}
/** Handles computations related to orbits */
declare class Orbit {
    params: OrbitData;
    private _quat;
    constructor(params: OrbitData);
    makePlot(): {
        line: THREE.Line;
        updateGeom: () => void;
    };
    private _updateQuaternion();
    /** Get the quaternion for the orbital plane. */
    getOrbitalQuaternion(): THREE.Quaternion;
    /**
     * Get position relative to ecliptic.
     */
    getPos(t: number, asTheta?: boolean, into?: Vector3, getVel?: any): THREE.Vector3;
    getVel(t: number, asTheta?: boolean): THREE.Vector3;
    /**
      * Get position relative to orbital plane at any given time.
      * If asTheta is false, then t is the current time, otherwise, t is true
      * anomaly.
      */
    getInPlanePos(t: number, asTheta?: boolean, into?: THREE.Vector3, getVel?: THREE.Vector3): THREE.Vector3;
}
declare class Rotation {
    params: RotationData;
    constructor(params: RotationData);
    getRotation(t: any): THREE.Quaternion;
}
